==> synimport-8.x-1.5.tar.gz: synimport/src/Service/Import.php <==
<?php

namespace Drupal\synimport\Service;

use Symfony\Component\Process\Process;
use Drupal\Core\Url;
use Drupal\pathauto\PathautoState;
use Drupal\Core\Config\FileStorage;
use Drupal\file\Entity\File;

/**
 * Defines Content Import.
 *
 * Contacts.
 *
 * Nodes Service.
 *
 * Taxonomy Service.
 *
 * Menu Service.
 *
 * Paragraph Service.
 *
 * Product Service.
 *
 * SynlandingConfig.
 *
 * @internal
 *   For internal usage by the Commerce synimport module.
 */

/**
 * Import service.
 */
class Import implements ImportInterface {
  /**
   * Files service.
   *
   * @var Drupal\synimport\Service\FilesImport
   */
  protected $filesImport;

  /**
   * Menu service.
   *
   * @var Drupal\synimport\Service\MenuImport
   */
  protected $menuImport;

  /**
   * Taxonomy service.
   *
   * @var Drupal\synimport\Service\TaxonomyImport
   */
  protected $taxonomyImport;

  /**
   * Node service.
   *
   * @var Drupal\synimport\Service\NodeImport
   */
  protected $nodeImport;

  /**
   * Product service.
   *
   * @var Drupal\synimport\Service\ProductImport
   */
  protected $productImport;

  /**
   * Block service.
   *
   * @var Drupal\synimport\Service\BlockImport
   */
  protected $blockImport;

  /**
   * Global logger variable.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $logger;

  /**
   * Controller constructor.
   */
  public function __construct(
    ImportInterface $filesImport,
    ImportInterface $menuImport,
    ImportInterface $taxonomyImport,
    ImportInterface $nodeImport,
    ImportInterface $productImport,
    ImportInterface $blockImport
  ) {
    $this->filesImport = $filesImport;
    $this->menuImport = $menuImport;
    $this->taxonomyImport = $taxonomyImport;
    $this->nodeImport = $nodeImport;
    $this->productImport = $productImport;
    $this->blockImport = $blockImport;
  }

  /**
   * {@inheritdoc}
   */
  public function setLogger($logger) {
    $this->logger = $logger;
  }

  /**
   * SendMessages to docker.
   */
  private function dockerLogger(string $msg) {
    $timeout = 60000;
    $cmd = "cd ../console/ && ./console.php tpl:echo '$msg'";
    $process = new Process($cmd);
    $process->setTimeout($timeout);
    $process->start();
    $process->wait();
    return [
      'success' => $process->isSuccessful(),
      'output' => $process->getOutput(),
      'error' => $process->getErrorOutput(),
    ];
  }

  /**
   * Import Full Content.
   */
  public function import(string $directory) {
    $this->dockerLogger("Start Contacts Import");
    $this->logger->warning('Start Contacts Import');
    $this->importContacts($directory);
    $this->logger->success('[Done Contacts Import]');
    $this->dockerLogger("[Done Contacts Import]");

    $this->dockerLogger("Start Menu Import");
    $this->logger->warning('Start Menu Import');
    $this->menuImport->import($directory);
    $this->logger->success('[Done Menu Import]');
    $this->dockerLogger("[Done Menu Import]");

    $this->dockerLogger("Start Taxonomy Import");
    $this->logger->warning('Start Taxonomy Import');
    $this->taxonomyImport->import($directory);
    $this->logger->success('[Done Taxonomy Import]');
    $this->dockerLogger("[Done Taxonomy Import]");

    $this->dockerLogger("Start Node Import");
    $this->logger->warning('Start Node Import');
    $this->nodeImport->import($directory);
    $this->logger->success('[Done Node Import]');
    $this->dockerLogger("[Done Node Import]");

    $this->dockerLogger("Start Product Import");
    $this->logger->warning('Start Product Import');
    $this->productImport->import($directory);
    $this->logger->success('[Done Product Import]');
    $this->dockerLogger("[Done Product Import]");

    $this->dockerLogger("Start Block Import");
    $this->logger->warning('Start Block Import');
    $this->blockImport->import($directory);
    $this->logger->success('[Done Block Import]');
    $this->dockerLogger("[Done Block Import]");

    $this->dockerLogger("Start Setting Synlanding Configs");
    $this->logger->warning('Start Setting Synlanding Configs');
    $this->setSynlandingFormBg($directory);
    $this->logger->success('[Done Setting Synlanding Configs]');
    $this->dockerLogger("[Done Setting Synlanding Configs]");
  }

  /**
   * Import Menu.
   */
  public function importMenu(string $directory) {
    $this->menuImport->import($directory);
  }

  /**
   * Import Taxonomy.
   */
  public function importTaxonomy(string $directory) {
    $this->logger->warning('Start Taxonomy Import');
    $this->taxonomyImport->import($directory);
    $this->logger->success('[Done Taxonomy Import]');
  }

  /**
   * Import Node.
   */
  public function importNode(string $directory) {
    $this->logger->warning('Start Node Import');
    $this->nodeImport->import($directory);
    $this->logger->success('[Done Node Import]');
  }

  /**
   * Import Products.
   */
  public function importProducts(string $directory) {
    $this->logger->warning('Start Product Import');
    $this->productImport->import($directory);
    $this->logger->success('[Done Product Import]');
  }

  /**
   * Import Blocks.
   */
  public function importBlocks(string $directory) {
    $this->blockImport->import($directory);
  }

  /**
   * Import Contacts.
   */
  public function importContacts(string $directory) {
    $sourceContacts = new FileStorage($directory . '/contacts');
    foreach ($sourceContacts->listAll() as $file) {
      $data = $sourceContacts->read($file);
      $path = \Drupal::service('path_alias.manager')->getPathByAlias('/contacts');
      if ($path == '/contacts') {
        $path = \Drupal::service('path_alias.manager')->getPathByAlias('/kontakty');
      }
      $params = Url::fromUri("internal:" . $path)->getRouteParameters();
      $entity_type = key($params);
      $node = \Drupal::entityTypeManager()->getStorage($entity_type)->load($params[$entity_type]);
      $node->body->format = $data['body']['format'];
      $node->body->value = $data['body']['value'];
      $node->path = [
        'alias' => $data['path'],
        'pathauto' => PathautoState::SKIP,
      ];
      $node->save();
    }
  }

  /**
   * Set Synlanding form background.
   */
  public function setSynlandingFormBg(string $directory) {
    $sourceSynLanding = new FileStorage($directory . '/synlanding');
    foreach ($sourceSynLanding->listAll() as $file) {
      $data = $sourceSynLanding->read($file);
      $imageId = $this->filesImport->importImages($data['form_bg_path']);
      $idFile = array_shift($imageId)['target_id'];
      $config = \Drupal::config($data['config_id']);
      \Drupal::configFactory()
        ->getEditable($data['config_id'])
        ->set('form_bg', [$idFile])
        ->save();
      $image = File::load($idFile);
      $file_usage = \Drupal::service('file.usage');
      $file_usage->add($image, 'synlanding', 'file', $idFile);
    }
  }

}

==> synimport-8.x-1.51.tar.gz: synimport/src/Service/Import.php <==
<?php

namespace Drupal\synimport\Service;

use Drupal\Core\Url;
use Drupal\pathauto\PathautoState;
use Drupal\Core\Config\FileStorage;
use Drupal\file\Entity\File;
use Drupal\synimport\Classes\EmptyDirException;
use Drupal\synimport\Classes\Logger;

/**
 * Defines Content Import.
 *
 * Contacts.
 *
 * Nodes Service.
 *
 * Taxonomy Service.
 *
 * Menu Service.
 *
 * Paragraph Service.
 *
 * Product Service.
 *
 * SynlandingConfig.
 *
 * @internal
 *   For internal usage by the Commerce synimport module.
 */

/**
 * Import service.
 */
class Import implements ImportInterface {
  /**
   * Files service.
   *
   * @var Drupal\synimport\Service\FilesImport
   */
  protected $filesImport;

  /**
   * Menu service.
   *
   * @var Drupal\synimport\Service\MenuImport
   */
  protected $menuImport;

  /**
   * Taxonomy service.
   *
   * @var Drupal\synimport\Service\TaxonomyImport
   */
  protected $taxonomyImport;

  /**
   * Node service.
   *
   * @var Drupal\synimport\Service\NodeImport
   */
  protected $nodeImport;

  /**
   * Product service.
   *
   * @var Drupal\synimport\Service\ProductImport
   */
  protected $productImport;

  /**
   * Block service.
   *
   * @var Drupal\synimport\Service\BlockImport
   */
  protected $blockImport;

  /**
   * Controller constructor.
   */
  public function __construct(
    ImportInterface $filesImport,
    ImportInterface $menuImport,
    ImportInterface $taxonomyImport,
    ImportInterface $nodeImport,
    ImportInterface $productImport,
    ImportInterface $blockImport
  ) {
    $this->filesImport = $filesImport;
    $this->menuImport = $menuImport;
    $this->taxonomyImport = $taxonomyImport;
    $this->nodeImport = $nodeImport;
    $this->productImport = $productImport;
    $this->blockImport = $blockImport;
    $this->logger = new Logger();
  }

  /**
   * Import Full Content.
   */
  public function import(string $directory) {
    $this->dirIsEmpty($directory . '/contacts', "Contacts");
    $this->logger->notice('Start Contacts Import');
    $this->importContacts($directory . '/contacts');
    $this->logger->success("[Done Contacts Import]");

    $this->dirIsEmpty($directory . '/menu', "Menu");
    $this->logger->notice('Start Menu Import');
    $this->menuImport->import($directory . '/menu');
    $this->logger->success("[Done Menu Import]");

    $this->dirIsEmpty($directory . '/taxonomy', "Taxonomy");
    $this->logger->notice('Start Taxonomy Import');
    $this->taxonomyImport->import($directory . '/taxonomy');
    $this->logger->success('[Done Taxonomy Import]');

    $this->dirIsEmpty($directory . '/nodes', "Node");
    $this->logger->notice('Start Node Import');
    $this->nodeImport->import($directory . '/nodes');
    $this->logger->success('[Done Node Import]');

    $this->dirIsEmpty($directory . '/products', "Product");
    $this->logger->notice('Start Product Import');
    $this->productImport->import($directory . '/products');
    $this->logger->success('[Done Product Import]');

    $this->dirIsEmpty($directory . '/block', "Block");
    $this->logger->notice('Start Block Import');
    $this->blockImport->import($directory . '/block');
    $this->logger->success('[Done Block Import]');

    $this->dirIsEmpty($directory . '/synlanding', "Synlanding Configs");
    $this->logger->notice('Start Setting Synlanding Configs');
    $this->setSynlandingFormBg($directory . '/synlanding');
    $this->logger->success('[Done Setting Synlanding Configs]');
  }

  /**
   * Import Menu.
   */
  public function importMenu(string $directory) {
    $this->logger->notice('Start Menu Import');
    $this->menuImport->import($directory);
    $this->logger->success("[Done Menu Import]");
  }

  /**
   * Import Taxonomy.
   */
  public function importTaxonomy(string $directory) {
    $this->logger->notice('Start Taxonomy Import');
    $this->taxonomyImport->import($directory);
    $this->logger->success('[Done Taxonomy Import]');
  }

  /**
   * Import Node.
   */
  public function importNode(string $directory) {
    $this->logger->notice('Start Node Import');
    $this->nodeImport->import($directory);
    $this->logger->success('[Done Node Import]');
  }

  /**
   * Import Products.
   */
  public function importProducts(string $directory) {
    $this->logger->notice('Start Product Import');
    $this->productImport->import($directory);
    $this->logger->success('[Done Product Import]');
  }

  /**
   * Import Blocks.
   */
  public function importBlocks(string $directory) {
    $this->logger->notice('Start Block Import');
    $this->blockImport->import($directory);
    $this->logger->success('[Done Block Import]');
  }

  /**
   * Import Contacts.
   */
  public function importContacts(string $directory) {
    $sourceContacts = new FileStorage($directory);
    foreach ($sourceContacts->listAll() as $file) {
      $data = $sourceContacts->read($file);
      $path = \Drupal::service('path_alias.manager')->getPathByAlias('/contacts');
      if ($path == '/contacts') {
        $path = \Drupal::service('path_alias.manager')->getPathByAlias('/kontakty');
      }
      $params = Url::fromUri("internal:" . $path)->getRouteParameters();
      $entity_type = key($params);
      $node = \Drupal::entityTypeManager()->getStorage($entity_type)->load($params[$entity_type]);
      $node->body->format = $data['body']['format'];
      $node->body->value = $data['body']['value'];
      $node->path = [
        'alias' => $data['path'],
        'pathauto' => PathautoState::SKIP,
      ];
      $node->save();
    }
  }

  /**
   * Set Synlanding form background.
   */
  public function setSynlandingFormBg(string $directory) {
    $sourceSynLanding = new FileStorage($directory);
    foreach ($sourceSynLanding->listAll() as $file) {
      $data = $sourceSynLanding->read($file);
      $imageId = $this->filesImport->importImages($data['form_bg_path']);
      $idFile = array_shift($imageId)['target_id'];
      $config = \Drupal::config($data['config_id']);
      \Drupal::configFactory()
        ->getEditable($data['config_id'])
        ->set('form_bg', [$idFile])
        ->save();
      $image = File::load($idFile);
      $file_usage = \Drupal::service('file.usage');
      $file_usage->add($image, 'synlanding', 'file', $idFile);
    }
  }

  /**
   * Check for empty directory.
   *
   * @throws Drupal\synimport\Classes\EmptyDirException
   *
   *   No file input.
   */
  private function dirIsEmpty(string $dirname, string $dirtype) {
    if (!file_exists($dirname)) {
      $this->logger->warning("No $dirtype directory");
      return TRUE;
    }
    foreach (scandir($dirname) as $file) {
      if (!in_array($file, ['.', '..', '.svn', '.git'])) {
        return FALSE;
      }
    }
    $this->logger->warning("$dirtype is empty");
    return TRUE;
  }
  
}
